Locale class

Constructors

Locale({required String language, required String country})
const

Properties

country String
final
hashCode int
The hash code for this object.
no setterinherited
language String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

english → const Locale
uk → const Locale
us → const Locale