PhoneParserTextInputFormatter class

Formats a phone number as digits are entered.

Constructors

PhoneParserTextInputFormatter({required String isoCode, NsnFormat format = NsnFormat.national, int digitLimit = maxDigits})

Properties

currentOutput String
The formatted output for the digits entered so far.
no setter
digitLimit int
final
format NsnFormat
final
hashCode int
The hash code for this object.
no setterinherited
hasLeadingPlus bool
Whether the current input started with a leading plus sign.
no setter
isoCode String
final
normalizedDigits String
Current normalized numeric input, excluding a leading plus sign.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears all previously entered input.
inputDigit(String input) String
Adds one or more characters and returns the formatted output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeLastDigit() String
Removes the last entered digit and returns the formatted output.
replace(String input) String
Replaces all current input with input and returns the formatted output.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxDigits → const int