MetadataFinder class abstract
Helper to find metadata
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
info
↔ Map<
String, dynamic> -
getter/setter pair
-
supportedCallingCodes
→ List<
String> -
no setter
-
supportedRegions
→ List<
String> -
no setter
Static Methods
-
countryCodeToIsoCode(
String countryCode) → List< String> -
findMetadataExamplesForIsoCode(
String isoCode) → Map< String, String> -
findMetadataForCountryCode(
String countryCode, String nationalNumber) → Map< String, dynamic> ? -
findMetadataForIsoCode(
String isoCode) → Map< String, dynamic> - expects a normalized iso code
-
findMetadataFormatsForIsoCode(
String isoCode) → List -
findMetadataLengthForIsoCode(
String isoCode) → Map< String, List< int> > -
findMetadataPatternsForIsoCode(
String isoCode) → Map< String, dynamic> - expects a normalized iso code
-
getCountryCodeForRegion(
String isoCode) → String? -
getMetadata(
) → Map< String, Map< String, dynamic> > -
getRegionCodeForCountryCode(
String countryCode) → String? -
getRegionCodeForNumber(
String countryCode, String nationalNumber) → String? -
getRegionCodesForCountryCode(
String countryCode) → List< String> -
getSupportedTypesForRegion(
String isoCode) → List< PhoneNumberType> -
readMetadataJson(
String downloadDir, {List< MetadataSource> sources = const [MetadataSource.googleLibphonenumber, MetadataSource.applePhoneNumberKit]}) → Future<void> - Loads and caches parsed metadata for all supported regions.