PhoneNumberUtil class
Utility facade for callers who prefer a libphonenumber-style API surface.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findNumbers(
String text) → Iterable< PhoneNumber> -
format(
PhoneNumber phoneNumber, {String? isoCode, NsnFormat format = NsnFormat.national}) → String -
getAsYouTypeFormatter(
String isoCode, {NsnFormat format = NsnFormat.national}) → PhoneParserTextInputFormatter -
getDescriptionForNumber(
PhoneNumber phoneNumber, Locale locale, [String? userRegion]) → String -
getNumberType(
PhoneNumber phoneNumber) → PhoneNumberType -
isNumberMatch(
Object firstNumber, Object secondNumber) → MatchType -
isPossibleNumber(
PhoneNumber phoneNumber, {PhoneNumberType? type}) → bool -
isValidNumber(
PhoneNumber phoneNumber, {PhoneNumberType? type}) → bool -
isValidNumberForRegion(
PhoneNumber phoneNumber, String regionCode, {PhoneNumberType? type}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String phoneNumber, {String? callerCountry, String? destinationCountry}) → PhoneNumber -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PhoneNumberUtil
-
final